GradientPreset class

Constructors

GradientPreset()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

agileLane → const List<Color>
alihossein → const List<Color>
amazon → const List<Color>
azureLane → const List<Color>
blackRose → const List<Color>
blueRaspberry → const List<Color>
boogieWonderland → const List<Color>
burningOrange → const List<Color>
burningRed → const List<Color>
cherryBlossom → const List<Color>
citrusPeel → const List<Color>
coolBlues → const List<Color>
copper → const List<Color>
coral → const List<Color>
cosmicFusion → const List<Color>
crystalClear → const List<Color>
dawn → const List<Color>
deepSpace → const List<Color>
desolate → const List<Color>
diesel → const List<Color>
digitalWater → const List<Color>
dimension → const List<Color>
electricViolet → const List<Color>
emeraldWater → const List<Color>
eveningSunshine → const List<Color>
firefox → const List<Color>
firewatch → const List<Color>
flickr → const List<Color>
freeLife → const List<Color>
freshTurboscent → const List<Color>
frozen → const List<Color>
greenBeach → const List<Color>
harmfulRed → const List<Color>
harmonious → const List<Color>
honeydew → const List<Color>
hourglass → const List<Color>
intuition → const List<Color>
jShine → const List<Color>
kelp → const List<Color>
lemonTwist → const List<Color>
levi → const List<Color>
lieToMe → const List<Color>
loveCouple → const List<Color>
lush → const List<Color>
malibuBeach → const List<Color>
megaTron → const List<Color>
moodyBlues → const List<Color>
motherRussia → const List<Color>
neonLife → const List<Color>
nostalgia → const List<Color>
oasis → const List<Color>
oceanBlue → const List<Color>
overSun → const List<Color>
paradox → const List<Color>
peaceful → const List<Color>
peep → const List<Color>
pharoah → const List<Color>
piggyPink → const List<Color>
pinkDream → const List<Color>
pureLust → const List<Color>
purpleBliss → const List<Color>
purpleLove → const List<Color>
purpleParadise → const List<Color>
quepal → const List<Color>
radar → const List<Color>
rainbow → const List<Color>
reef → const List<Color>
reflection → const List<Color>
richMetal → const List<Color>
rose → const List<Color>
roseanna → const List<Color>
roseWater → const List<Color>
royalBlue → const List<Color>
shifter → const List<Color>
silver → const List<Color>
slidenjoy → const List<Color>
spaceShift → const List<Color>
springWarmth → const List<Color>
strongBliss → const List<Color>
subu → const List<Color>
sunrise → const List<Color>
tarnish → const List<Color>
theStrain → const List<Color>
tremors → const List<Color>
warmFlame → const List<Color>
warmy → const List<Color>
whinehouse → const List<Color>
witchingHour → const List<Color>
zeusMiracle → const List<Color>